summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h')
-rw-r--r--TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h b/TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h
index e1396f9c7d4..8a56836c0f1 100644
--- a/TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h
+++ b/TAO/orbsvcs/ImplRepo_Service/Adapter_Activator.h
@@ -16,7 +16,6 @@
#include "tao/PortableServer/PortableServer.h"
#include "tao/PortableServer/AdapterActivatorC.h"
-#include "tao/PortableServer/ServantLocatorC.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
@@ -24,16 +23,18 @@
#include "tao/LocalObject.h"
+class TAO_ServantBase;
+
/**
* @class ImR_Adapter_Activator
*
* @brief Implementation Repository Adapter Activator
*
* Part of the ServantLocator/AdapterActivator combination that is used to
* receive forwardable requests from clients. The Adapter Activator creates
* the POA structure that the request expects. For each POA created, the
* same ServantLocator will be registered in each one.
*/
class ImR_Adapter
: public PortableServer::AdapterActivator,
@@ -48,10 +49,10 @@ public:
const char *name
);
- void init(PortableServer::ServantLocator_ptr servant);
+ void init(TAO_ServantBase * servant);
private:
- /// The ServantLocator registered in each new POA.
- PortableServer::ServantLocator_ptr servant_locator_;
+ /// the default servant used.
+ TAO_ServantBase *default_servant_;
};
#endif /* IMR_ADAPTER_ACTIVATOR_H */
@@ -24,16 +23,18 @@
* @brief Implementation Repository Adapter Activator
*
- * Part of the ServantLocator/AdapterActivator combination that is used to
+ * Part of the DefaultServant/AdapterActivator combination that is used to
* receive forwardable requests from clients. The Adapter Activator creates
* the POA structure that the request expects. For each POA created, the
@@ -24,16 +23,18 @@
* receive forwardable requests from clients. The Adapter Activator creates
* the POA structure that the request expects. For each POA created, the
- * same ServantLocator will be registered in each one.
+ * same DefaultServant will be registered in each one.
*/
class ImR_Adapter